```
model wcb_factor 
  "Calculates the fraction [0..1] of released maximum heat flow rate to the maximum heat flow rate for the two wood chip burners"
  extends Modelica.Blocks.Icons.Block;
  extends BlockDisplay(number=wcb_factor);

  outer SFJV.Parameters.NominalValues nom "Record with nominal (design) values";

  // Nominal values
  parameter SI.HeatFlowRate[2] Q_flow_wcb_nom=nom.Q_flow_wcb 
    "Nominal boiler heat flow rates"
    annotation (Dialog(group="Nominal values (design)"));

  Modelica.Blocks.Interfaces.RealOutput wcb_factor ;
protected 
  Modelica.Blocks.Math.BooleanToReal[2] wcb_release_real;
public 
  Modelica.Blocks.Interfaces.BooleanInput release_wcb1;
  Modelica.Blocks.Interfaces.BooleanInput release_wcb2;
equation 
  connect(release_wcb1, wcb_release_real[1].u);
  connect(release_wcb2, wcb_release_real[2].u);

  // Calculate HP multiplier
  wcb_factor = wcb_release_real.y*Q_flow_wcb_nom/sum(Q_flow_wcb_nom);

end wcb_factor;
```